@@ -39,6 +39,10 @@ import yaml
 import uuid
 import string
 import random
+import threading
+from threading import Thread
+import glob
+import re
 import xml.etree.ElementTree as ET
 sns.set(color_codes=True)
 
@@ -1149,4 +1153,73 @@ class ConfigHandler:
             configGen.by_file("../../config.values.txt",config_path)
         # If it's launched via DevOps, then the values will be pass as params
         else:
-            configGen.by_args(sys.argv, config_path)
\ No newline at end of file
+            configGen.by_args(sys.argv, config_path)
+
+class VectorsInternalDataSpliter:
+    def split(self, data, counter):
+        assert len(data) == 3
+        X, y, ids = data
+        limite = len(X)//counter
+        print("len(X)/counter", len(X)/counter)
+        print("limite", limite)
+        result = []
+        X_result, y_result, ids_result = [],[],[]
+        print("len(X) :", len(X))
+        for item in zip(X,y,ids):
+            X_local, y_local, ids_local = item
+            X_result.append(X_local)
+            y_result.append(y_local)
+            ids_result.append(ids_local)
+            if len(X_result) == limite:
+                print("len(X_result) :",len(X_result))
+                result.append((X_result,y_result,ids_result))
+                X_result, y_result, ids_result = [],[],[]
+
+        if len(X_result) > 0:
+            print("again len(X_result) : ", len(X_result))
+            result.append((X_result,y_result,ids_result))
+        
+        return result
+
+class VectorsInternalSplitedDataReader:
+    def read(self, directory_path):
+        X_result, y_result, ids_result = [],[],[]
+        for file in os.listdir(directory_path):
+            if re.match(r'^.*_block_[0-9]+.*', file):
+                print("file :", file)
+                data_vec = PickleUtilities.load_file(os.path.join(directory_path, file))
+                X,y,ids = data_vec
+                X_result.append(X)
+                y_result.append(y)
+                ids_result.append(ids)
+            else:
+                raise Exception("The {0} file does not follow the criterion <text>_block_<number>".format(file))
+        
+        result = X_result, y_result, ids_result
+        return result
+
+class LargeFileWriter:
+    def _create_block_file(self, data,prefix,index, directory_path, ext):
+        
+        if "." in ext:
+            ext = ext.replace(".", "")
+
+        file = os.path.join(directory_path, "{0}_block_{1}.{2}".format(prefix, index, ext))
+        joblib.dump(data, file)
+        print(file, " finished!")
+    
+    def write(self, data_list,prefix,directory_path, ext):
+        threadlist = []
+        for index, data in enumerate(data_list):
+            t = Thread(target=self._create_block_file, args=(data, prefix,index, directory_path, ext))
+            threadlist.append(t)
+
+        for _thread in threadlist:
+            _thread.start()
+        
+        for _thread in threadlist:
+            _thread.join()
+
+    #def read(self, directory_path, prefix, ext):
+    #    files = [f for f in os.listdir(directory_path) if re.match(r'^.*_block_[0-9]+.*', f)]
+
